@@ -1,11 +1,11 @@
 from jeepney import DBusAddress, new_method_call
-from jeepney.integrate.blocking import connect_and_authenticate
+from jeepney.io.blocking import open_dbus_connection
 
 notifications = DBusAddress('/org/freedesktop/Notifications',
                             bus_name='org.freedesktop.Notifications',
                             interface='org.freedesktop.Notifications')
 
-connection = connect_and_authenticate(bus='SESSION')
+connection = open_dbus_connection(bus='SESSION')
 
 # Construct a new D-Bus message. new_method_call takes the address, the
 # method name, the signature string, and a tuple of arguments.
@@ -21,6 +21,6 @@ msg = new_method_call(notifications, 'Notify', 'susssasa{sv}i',
 
 # Send the message and wait for the reply
 reply = connection.send_and_get_reply(msg)
-print('Notification ID:', reply[0])
+print('Notification ID:', reply.body[0])
 
 connection.close()
